import{defineComponent as a,mergeModels as s,useModel as d,computed as u,openBlock as n,createBlock as f,withCtx as c,createVNode as g,unref as t,mergeProps as w}from"vue";import V from"primevue/inputtext";import{c as x}from"./index-CU6LcO2W.js";import{f as P,I as _}from"./widgetPropFilter-CygYoMQt.js";import{W as I}from"./index-CqZHjtQN.js";import{_ as C}from"./WidgetLayoutField.vue_vue_type_script_setup_true_lang-Azr_vpNt.js";import"@primevue/themes";import"@primevue/themes/aura";import"./vendor-other-BpgYsL4Z.js";import"./vendor-vue-C7sAPp8E.js";import"primevue/config";import"primevue/confirmationservice";import"primevue/toastservice";import"primevue/tooltip";import"primevue/button";import"vue-i18n";import"primevue/message";import"primevue/skeleton";import"primevue/multiselect";import"primevue/select";import"primevue/checkbox";import"primevue/divider";import"primevue/scrollpanel";import"primevue/usetoast";import"primevue/card";import"primevue/listbox";import"primevue/progressbar";import"primevue/floatlabel";import"@primevue/forms";import"@primevue/forms/resolvers/zod";import"primevue/password";import"primevue/progressspinner";import"primevue/tag";import"primevue/inputnumber";import"primevue/tabpanels";import"primevue/tabs";import"primevue/iconfield";import"primevue/inputicon";import"primevue/badge";import"primevue/chip";import"primevue/tabpanel";import"primevue/toggleswitch";import"primevue/colorpicker";import"primevue/radiobutton";import"primevue/knob";import"primevue/slider";import"primevue/panel";import"primevue/tabmenu";import"primevue/popover";import"primevue/tab";import"primevue/tablist";import"primevue";import"primevue/autocomplete";import"primevue/dropdown";import"./vendor-xterm-DV1MVhAx.js";import"./vendor-three-zdhtZbSm.js";import"primevue/galleria";import"primevue/contextmenu";import"primevue/tree";import"primevue/toolbar";import"primevue/selectbutton";import"primevue/dialog";import"primevue/confirmpopup";import"primevue/useconfirm";import"primevue/confirmdialog";import"./vendor-tiptap-mfowjb53.js";import"primevue/blockui";const zt=a({__name:"WidgetInputText",props:s({widget:{}},{modelValue:{default:""},modelModifiers:{}}),emits:["update:modelValue"],setup(o){const p=o,r=d(o,"modelValue"),e=u(()=>P(p.widget.options,_));return(m,i)=>(n(),f(C,{widget:m.widget},{default:c(()=>[g(t(V),w({modelValue:r.value,"onUpdate:modelValue":i[0]||(i[0]=l=>r.value=l)},e.value,{class:t(x)(t(I),"w-full text-xs py-2 px-4"),"aria-label":m.widget.name,size:"small",pt:{root:"truncate min-w-[4ch]"}}),null,16,["modelValue","class","aria-label"])]),_:1},8,["widget"]))}});export{zt as default};
//# sourceMappingURL=WidgetInputText-CR17-H7l.js.map
