import{defineComponent as c,openBlock as a,createElementBlock as t,unref as u,createElementVNode as m}from"vue";import{c1 as g,aS as f}from"./vendor-other-BpgYsL4Z.js";const p={class:"relative size-full overflow-hidden rounded bg-modal-card-placeholder-background"},h=["src","alt"],v={key:1,class:"flex size-full items-center justify-center bg-modal-card-placeholder-background"},b=c({__name:"MediaImageTop",props:{asset:{}},emits:["image-loaded"],setup(s,{emit:o}){const n=o,{state:e,error:i,isReady:d}=g({src:s.asset.src??"",alt:s.asset.name});return f(()=>d.value&&e.value?.naturalWidth&&e.value?.naturalHeight,()=>n("image-loaded",e.value.naturalWidth,e.value.naturalHeight)),(l,r)=>(a(),t("div",p,[u(i)?(a(),t("div",v,r[0]||(r[0]=[m("i",{class:"pi pi-image text-3xl text-muted-foreground"},null,-1)]))):(a(),t("img",{key:0,src:l.asset.src,alt:l.asset.name,class:"size-full object-contain transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105"},null,8,h))]))}});export{b as default};
//# sourceMappingURL=MediaImageTop-DcJijl43.js.map
