import{defineComponent as p,openBlock as l,createElementBlock as d,createElementVNode as i,toDisplayString as f,createCommentVNode as u,createVNode as m,withModifiers as r,unref as t,renderSlot as c}from"vue";import{L as a}from"./index-CU6LcO2W.js";import{cc as o}from"./vendor-other-BpgYsL4Z.js";const w={class:"flex h-[30px] min-w-0 items-center justify-between gap-1"},g={class:"relative flex h-full min-w-0 w-20 items-center"},v={key:0,class:"lod-toggle flex-1 truncate text-xs font-normal text-node-component-slot-text"},x={class:"relative min-w-0 flex-1"},L=p({__name:"WidgetLayoutField",props:{widget:{}},setup(_){return(s,e)=>(l(),d("div",w,[i("div",g,[s.widget.name?(l(),d("p",v,f(s.widget.label||s.widget.name),1)):u("",!0),m(a)]),i("div",x,[i("div",{class:"lod-toggle cursor-default min-w-0",onPointerdown:e[0]||(e[0]=r((...n)=>t(o)&&t(o)(...n),["stop"])),onPointermove:e[1]||(e[1]=r((...n)=>t(o)&&t(o)(...n),["stop"])),onPointerup:e[2]||(e[2]=r((...n)=>t(o)&&t(o)(...n),["stop"]))},[c(s.$slots,"default")],32),m(a)])]))}});export{L as _};
//# sourceMappingURL=WidgetLayoutField.vue_vue_type_script_setup_true_lang-Azr_vpNt.js.map
