import{defineComponent as a,mergeModels as d,useModel as s,computed as n,openBlock as u,createElementBlock as f,createVNode as m,unref as t,mergeProps as c}from"vue";import g from"primevue/textarea";import{c as w,L as V}from"./index-CU6LcO2W.js";import{f as P,I as b}from"./widgetPropFilter-CygYoMQt.js";import{W as h}from"./index-CqZHjtQN.js";import"@primevue/themes";import"@primevue/themes/aura";import"./vendor-other-BpgYsL4Z.js";import"./vendor-vue-C7sAPp8E.js";import"primevue/config";import"primevue/confirmationservice";import"primevue/toastservice";import"primevue/tooltip";import"primevue/button";import"vue-i18n";import"primevue/message";import"primevue/skeleton";import"primevue/multiselect";import"primevue/inputtext";import"primevue/select";import"primevue/checkbox";import"primevue/divider";import"primevue/scrollpanel";import"primevue/usetoast";import"primevue/card";import"primevue/listbox";import"primevue/progressbar";import"primevue/floatlabel";import"@primevue/forms";import"@primevue/forms/resolvers/zod";import"primevue/password";import"primevue/progressspinner";import"primevue/tag";import"primevue/inputnumber";import"primevue/tabpanels";import"primevue/tabs";import"primevue/iconfield";import"primevue/inputicon";import"primevue/badge";import"primevue/chip";import"primevue/tabpanel";import"primevue/toggleswitch";import"primevue/colorpicker";import"primevue/radiobutton";import"primevue/knob";import"primevue/slider";import"primevue/panel";import"primevue/tabmenu";import"primevue/popover";import"primevue/tab";import"primevue/tablist";import"primevue";import"primevue/autocomplete";import"primevue/dropdown";import"./vendor-xterm-DV1MVhAx.js";import"./vendor-three-zdhtZbSm.js";import"primevue/galleria";import"primevue/contextmenu";import"primevue/tree";import"primevue/toolbar";import"primevue/selectbutton";import"primevue/dialog";import"primevue/confirmpopup";import"primevue/useconfirm";import"primevue/confirmdialog";import"./vendor-tiptap-mfowjb53.js";import"primevue/blockui";const v={class:"widget-expands relative"},zo=a({__name:"WidgetTextarea",props:d({widget:{},placeholder:{default:""}},{modelValue:{default:""},modelModifiers:{}}),emits:["update:modelValue"],setup(r){const e=s(r,"modelValue"),p=n(()=>P(r.widget.options,b));return(o,i)=>(u(),f("div",v,[m(t(g),c({modelValue:e.value,"onUpdate:modelValue":i[0]||(i[0]=l=>e.value=l)},p.value,{class:t(w)(t(h),"size-full text-xs lod-toggle resize-none"),placeholder:o.placeholder||o.widget.name||"","aria-label":o.widget.name,readonly:o.widget.options?.read_only,disabled:o.widget.options?.read_only,fluid:"","data-capture-wheel":"true"}),null,16,["modelValue","class","placeholder","aria-label","readonly","disabled"]),m(V)]))}});export{zo as default};
//# sourceMappingURL=WidgetTextarea-CD-GiY8F.js.map
