import{defineComponent as e,mergeModels as l,useModel as a,computed as d,openBlock as u,createBlock as s,withCtx as n,createVNode as f,unref as g,mergeProps as c}from"vue";import w from"primevue/toggleswitch";import{f as V,S as _}from"./widgetPropFilter-CygYoMQt.js";import{_ as P}from"./WidgetLayoutField.vue_vue_type_script_setup_true_lang-Azr_vpNt.js";import"./index-CU6LcO2W.js";import"@primevue/themes";import"@primevue/themes/aura";import"./vendor-other-BpgYsL4Z.js";import"./vendor-vue-C7sAPp8E.js";import"primevue/config";import"primevue/confirmationservice";import"primevue/toastservice";import"primevue/tooltip";import"primevue/button";import"vue-i18n";import"primevue/message";import"primevue/skeleton";import"primevue/multiselect";import"primevue/inputtext";import"primevue/select";import"primevue/checkbox";import"primevue/divider";import"primevue/scrollpanel";import"primevue/usetoast";import"primevue/card";import"primevue/listbox";import"primevue/progressbar";import"primevue/floatlabel";import"@primevue/forms";import"@primevue/forms/resolvers/zod";import"primevue/password";import"primevue/progressspinner";import"primevue/tag";import"primevue/inputnumber";import"primevue/tabpanels";import"primevue/tabs";import"primevue/iconfield";import"primevue/inputicon";import"primevue/badge";import"primevue/chip";import"primevue/tabpanel";import"primevue/colorpicker";import"primevue/radiobutton";import"primevue/knob";import"primevue/slider";import"primevue/panel";import"primevue/tabmenu";import"primevue/popover";import"primevue/tab";import"primevue/tablist";import"primevue";import"primevue/autocomplete";import"primevue/dropdown";import"./vendor-xterm-DV1MVhAx.js";import"./vendor-three-zdhtZbSm.js";import"primevue/galleria";import"primevue/contextmenu";import"primevue/tree";import"primevue/toolbar";import"primevue/selectbutton";import"primevue/dialog";import"primevue/confirmpopup";import"primevue/useconfirm";import"primevue/confirmdialog";import"./vendor-tiptap-mfowjb53.js";import"primevue/blockui";const Ro=e({__name:"WidgetToggleSwitch",props:l({widget:{}},{modelValue:{type:Boolean},modelModifiers:{}}),emits:["update:modelValue"],setup(o){const t=a(o,"modelValue"),r=d(()=>V(o.widget.options,_));return(i,m)=>(u(),s(P,{widget:i.widget},{default:n(()=>[f(g(w),c({modelValue:t.value,"onUpdate:modelValue":m[0]||(m[0]=p=>t.value=p)},r.value,{class:"ml-auto block","aria-label":i.widget.name}),null,16,["modelValue","aria-label"])]),_:1},8,["widget"]))}});export{Ro as default};
//# sourceMappingURL=WidgetToggleSwitch-iuEWFnwX.js.map
