var s=Object.defineProperty;var o=(t,e)=>s(t,"name",{value:e,configurable:!0});const u=o(t=>t.constructor.nodeData?.output_node,"isOutputNode"),r=o(t=>t.filter(u),"filterOutputNodes");export{r as f,u as i};
//# sourceMappingURL=nodeFilterUtil-D49mCu4H.js.map
