var c=Object.defineProperty;var a=(o,e)=>c(o,"name",{value:e,configurable:!0});import{defineComponent as d,computed as m,openBlock as l,createElementBlock as s,toDisplayString as p,createCommentVNode as f,createVNode as g,unref as u,mergeProps as _}from"vue";import w from"primevue/button";import{f as k,B}from"./widgetPropFilter-CygYoMQt.js";const C={class:"flex flex-col gap-1"},P={key:0,class:"text-secondary text-sm"},N=d({__name:"WidgetButton",props:{widget:{}},setup(o){const e=o,i=[...B,"iconClass"],n=m(()=>k(e.widget.options,i)),r=a(()=>{e.widget.callback&&e.widget.callback()},"handleClick");return(t,b)=>(l(),s("div",C,[t.widget.name?(l(),s("label",P,p(t.widget.name),1)):f("",!0),g(u(w),_(n.value,{"aria-label":t.widget.name||t.widget.label,size:"small",onClick:r}),null,16,["aria-label"])]))}});export{N as default};
//# sourceMappingURL=WidgetButton-ABbp6WPt.js.map
