import{defineComponent as u,computed as o,openBlock as c,createBlock as d,unref as f,withCtx as a,createElementVNode as l}from"vue";import g from"primevue/imagecompare";const b=["src","alt"],m=["src","alt"],h=u({__name:"WidgetImageCompare",props:{widget:{}},setup(r){const t=r,n=o(()=>{const e=t.widget.value;return typeof e=="string"?e:e?.before||""}),i=o(()=>{const e=t.widget.value;return typeof e=="string"?"":e?.after||""}),s=o(()=>{const e=t.widget.value;return typeof e=="object"&&e?.beforeAlt?e.beforeAlt:"Before image"}),p=o(()=>{const e=t.widget.value;return typeof e=="object"&&e?.afterAlt?e.afterAlt:"After image"});return(e,v)=>(c(),d(f(g),{tabindex:e.widget.options?.tabindex??0,"aria-label":e.widget.options?.ariaLabel,"aria-labelledby":e.widget.options?.ariaLabelledby,pt:e.widget.options?.pt,"pt-options":e.widget.options?.ptOptions,unstyled:e.widget.options?.unstyled},{left:a(()=>[l("img",{src:n.value,alt:s.value,class:"h-full w-full object-cover"},null,8,b)]),right:a(()=>[l("img",{src:i.value,alt:p.value,class:"h-full w-full object-cover"},null,8,m)]),_:1},8,["tabindex","aria-label","aria-labelledby","pt","pt-options","unstyled"]))}});export{h as default};
//# sourceMappingURL=WidgetImageCompare-C5Rl072v.js.map
