import{defineComponent as p,computed as e,openBlock as o,createElementBlock as i,createVNode as s,createElementVNode as a,toDisplayString as n,unref as c,createCommentVNode as l}from"vue";import{cT as f,cN as d}from"./index-CU6LcO2W.js";import{_ as u}from"./MediaTitle.vue_vue_type_script_setup_true_lang-CJ9ufLOs.js";import"@primevue/themes";import"@primevue/themes/aura";import"./vendor-other-BpgYsL4Z.js";import"./vendor-vue-C7sAPp8E.js";import"primevue/config";import"primevue/confirmationservice";import"primevue/toastservice";import"primevue/tooltip";import"primevue/button";import"vue-i18n";import"primevue/message";import"primevue/skeleton";import"primevue/multiselect";import"primevue/inputtext";import"primevue/select";import"primevue/checkbox";import"primevue/divider";import"primevue/scrollpanel";import"primevue/usetoast";import"primevue/card";import"primevue/listbox";import"primevue/progressbar";import"primevue/floatlabel";import"@primevue/forms";import"@primevue/forms/resolvers/zod";import"primevue/password";import"primevue/progressspinner";import"primevue/tag";import"primevue/inputnumber";import"primevue/tabpanels";import"primevue/tabs";import"primevue/iconfield";import"primevue/inputicon";import"primevue/badge";import"primevue/chip";import"primevue/tabpanel";import"primevue/toggleswitch";import"primevue/colorpicker";import"primevue/radiobutton";import"primevue/knob";import"primevue/slider";import"primevue/panel";import"primevue/tabmenu";import"primevue/popover";import"primevue/tab";import"primevue/tablist";import"primevue";import"primevue/autocomplete";import"primevue/dropdown";import"./vendor-xterm-DV1MVhAx.js";import"./vendor-three-zdhtZbSm.js";import"primevue/galleria";import"primevue/contextmenu";import"primevue/tree";import"primevue/toolbar";import"primevue/selectbutton";import"primevue/dialog";import"primevue/confirmpopup";import"primevue/useconfirm";import"primevue/confirmdialog";import"./vendor-tiptap-mfowjb53.js";import"primevue/blockui";const _={class:"flex flex-col items-center gap-1"},x={key:0,class:"flex items-center text-xs text-zinc-400"},St=p({__name:"MediaVideoBottom",props:{asset:{},context:{}},setup(m){const r=e(()=>f(m.asset.name).filename);return(t,N)=>(o(),i("div",_,[s(u,{"file-name":r.value},null,8,["file-name"]),t.asset.size?(o(),i("div",x,[a("span",null,n(c(d)(t.asset.size)),1)])):l("",!0)]))}});export{St as default};
//# sourceMappingURL=MediaVideoBottom-DTcKomHa.js.map
